#
# spec file for package courier-unicode
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname   lib%{name}
%define libsoname %{libname}8

Name:           courier-unicode
Version:        2.3.1
Release:        1.3
Summary:        Courier Unicode Library
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Servers
URL:            https://www.courier-mta.org/
Source0:        https://download.sourceforge.net/courier/%{name}-%{version}.tar.bz2
Source1:        https://download.sourceforge.net/courier/%{name}-%{version}.tar.bz2.sig
# Keyring downloaded from https://www.courier-mta.org/KEYS.bin#/%%{name}.keyring
Source2:        %{name}.keyring
BuildRequires:  fdupes
BuildRequires:  gcc-c++

%description
The Courier Unicode Library based on the Unicode 13.0.0 standard.
This package holds all man pages.

%package -n %{libsoname}
Summary:        Courier Unicode Library
Group:          System/Libraries

%description -n %{libsoname}
This library implements several algorithms related to the Unicode Standard:
* Look up uppercase, lowercase, and titlecase equivalents of a unicode
  character.
* Implementation of grapheme and work breaking rules.
* Implementation of line breaking rules.
* Several ancillary functions, like looking up the unicode character
  that corresponds to some HTML 4.0 entity (such as “&amp;”, for
  example), and determining the normal width or a double-width status of
  a unicode character. Also, an adaptation of the iconv(3) API for this
  unicode library.
This library also implements C++ bindings for these algorithms.

%package devel
Summary:        Courier Unicode Library - Development files
Group:          Development/Languages/C and C++
Requires:       %{libsoname} = %{version}
Provides:       %{libname}-devel

%description devel
This package contains the files needed to compile programs that use the
libunicode library.

%package doc
Summary:        Courier Unicode Library - Docs and man pages
Group:          Productivity/Networking/Email/Servers
BuildArch:      noarch

%description doc
This package contains the docs and the man pages of the Courier Unicode Library

%prep
%setup -q

%build
%configure \
  --disable-static

make %{?_smp_mflags}

%install
%make_install

# cleanup *.la libs
find %{buildroot} -name %{libname}.la -exec rm {} \;

# fdupes
%fdupes -s %{buildroot}%{_mandir}/man3/

%post   -n %{libsoname} -p /sbin/ldconfig
%postun -n %{libsoname} -p /sbin/ldconfig

%files -n %{libsoname}
%defattr(-,root,root)
%license COPYING
%doc ChangeLog README
%{_libdir}/%{libname}.so.*

%files devel
%defattr(-,root,root)
%doc AUTHORS
%dir %{_datadir}/aclocal/
%{_datadir}/aclocal/%{name}*.m4
%{_libdir}/%{libname}.so
%{_includedir}/%{name}*.h

%files doc
%defattr(-,root,root)
%{_mandir}/man?/*

%changelog
* Thu Aug  8 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 2.3.1
  * courier-debuild: implement DEBGCC=default, to help with pbuilder.
* Fri Jan  5 2024 Arjen de Korte <suse+build@de-korte.org>
- update to 2.3.0
  * Unicode 15 update. Added unicode_derived_<name>() lookup for
    derived core properties. Added unicode_general_category_lookup()
    for general category lookups. Fix GB11 rule.
- update courier-unicode.keyring with new signing key
* Sun Dec  4 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 2.2.6
  * Debian/Ubuntu: update lintian overrides
- update to 2.2.5
  * Adjust deb packaging. Check /etc/lsb-release and include the
    distribution release in the deb package version, to faciliate
    updating to the same version of the package in an updated release.
* Sat Aug 20 2022 Arjen de Korte <suse+build@de-korte.org>
- update to 2.2.4
  * configure.ac: gcc 12, autotool updates.
  * Add scripts to create installable .deb packages, update
    documentation.
* Sat Mar 27 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 2.2.3
  * Fix compilation error on CentOS 7
* Sat Mar 20 2021 Arjen de Korte <suse+build@de-korte.org>
- update to 2.2.2
  * unicode_bidi.c: Implement unicode_bidi_combining(). Implement
    canonical and compatibility decomposition and canonical composition.
  * unicode_bidi.c (unicode_bidi_needs_embed): Make its return code
    what its documentation says its return code is.
  * Implement unicode_bidi_needs_embed(), unicode_bidi_cleaned_size(),
    unicode::bidi_override,
- update to 2.2.1
  * unicode_bidi_calc and unicode_bidi_calc_levels return a
    unicode_bidi_direction object, to indicate whether the
    computer paragraph embedding level was explicitly computed or
    defaulted.
  * unicode::bidi_calc - an empty string with an explicit embedding
    level should return the requested embedding level.
- update to 2.2
  * unicode::iconvert::convert, fix uninitialized variable.
  * Implement bidirectional algorithm, canonical or equivalent character
    mappings.
  * Unicode 13 update. Adds lookup of EastAsianWidth property, emoji
    property lookup, adds an alternative sequence-based grapheme API
    that handles multi-character emoji rules.
  * Add bidi property lookups.
- update source download URL
* Wed Nov 25 2020 Arjen de Korte <suse+build@de-korte.org>
- update to 2.1.2
  * Fixes a packaging error in 2.1.1 that results in broken manual page
    links (no code changes)
- update to 2.1.1
  * Fixes a bug that causes cone to garble some messages when showing
    them
* Tue Nov 12 2019 Arjen de Korte <suse+build@de-korte.org>
- add courier-unicode.keyring for source verification
- cleanup spec
* Fri Dec 28 2018 ikruis@gmail.com
- update to 2.1
  * gcc 8 update, fix assertions. libtool and toolchain updates.
  * unicode.c: Implement unicode_x_smap_modutf8 pseudo-encoding.
  * unicode.c: Fix error and validation of valid modified-utf7
    encoding.
* Mon Dec  4 2017 suse+build@de-korte.org
- update to 2.0
  * configure.ac: Better test for available of nl_langinfo_l().
  * Migrate to C++11: remove unicode_char, use char32_t. Replace
    std::vector<unicode_char> with std::u32string.
* Mon May 16 2016 chris@computersalat.de
- update to 1.4
  * no info about changes available
* Wed Aug  5 2015 chris@computersalat.de
- update to 1.3
  * all: rebased against Unicode 8
  * courier-unicode: Rename unicode.h, library name, to avoid name
    clashing with some old, forgotten, Gnome library.
  * all: rebased against Unicode 7. Added unicode_script(), tr24
    Scripts lookup.
- fix spec for submit to Factory
* Wed Oct 29 2014 chris@computersalat.de
- initial pkg 1.1
